@@ -7,7 +7,7 @@
 
  COPYRIGHT:
 
- Copyright 2017 Jean-Romain Roussel
+ Copyright 2017-2019 Jean-Romain Roussel
 
  This file is part of lidR R package.
 
@@ -30,25 +30,33 @@
 #include <Rcpp.h>
 #include "QuadTree.h"
 #include "Progress.h"
+#include "myomp.h"
 
 using namespace Rcpp;
 
 // [[Rcpp::export]]
-IntegerVector C_tsearch(NumericVector x, NumericVector y, IntegerMatrix elem, NumericVector xi, NumericVector yi)
+IntegerVector C_tsearch(NumericVector x, NumericVector y, IntegerMatrix elem, NumericVector xi, NumericVector yi, int ncpu)
 {
   QuadTree tree(xi, yi);
 
   int nelem = elem.nrow();
   int np = xi.size();
 
-  Progress p(nelem, "Searching in TIN: ");
+  bool abort = false;
+
+  Progress pb(nelem, "Searching in TIN: ");
 
   IntegerVector output(np);
   std::fill(output.begin(), output.end(), NA_INTEGER);
 
   // Loop over each triangle
+  #pragma omp parallel for num_threads(ncpu)
   for (int k = 0; k < nelem; k++)
   {
+    if (abort) continue;
+    if (pb.check_interrupt()) abort = true; // No data race here because only thread 0 can actually write
+    pb.increment();
+
     // Retrieve triangle A B C coordinates
     int iA = elem(k, 0) - 1;
     int iB = elem(k, 1) - 1;
@@ -63,17 +71,17 @@ IntegerVector C_tsearch(NumericVector x, NumericVector y, IntegerMatrix elem, Nu
     tree.lookup(triangle, points);
 
     // Return the id of the triangle
-    for(std::vector<Point*>::iterator it = points.begin(); it != points.end(); it++)
+    #pragma omp critical
     {
+      for(std::vector<Point*>::iterator it = points.begin(); it != points.end(); it++)
+      {
         int id = (*it)->id;
         output(id) = k + 1;
+      }
     }
-
-    if (p.check_abort())
-      p.exit();
-
-    p.update(k);
   }
 
+  if (abort) throw Rcpp::internal::InterruptedException();
+
   return(output);
 }
